@@ -14,23 +14,41 @@ class Band:
     """
     This class contains all the methods for constructing band structures
     from the outputs of VASP band structure calculations.
+
+    Parameters:
+        folder (str): This is the folder that contains the VASP files
+        projected (bool): Determined wheter of not to parte the projected
+            eigenvalues from the vasprun.xml file. Making this true
+            increases the computational time, so only use if a projected
+            band structure is required.
+        hse (bool): Determines if the KPOINTS file is in the form of HSE
+            or not. Only make true if the band structure was calculated
+            using a hybrid functional.
+        spin (str): Choose which spin direction to parse. ('up' or 'down')
+        kpath (str): High symmetry k-point path of band structure calculation
+            Due to the nature of the KPOINTS file for HSE calculations this
+            information is a required input for proper labeling of the figure
+            for HSE calculations. This information is extracted from the KPOINTS
+            files for non-HSE calculations. (G is automaticall converted to \\Gamma)
+        n (int): Number of points between each high symmetry points.
+            This is also only required for HSE calculations. This number should be 
+            known by the user, as it was used to generate the KPOINTS file.
     """
 
     def __init__(self, folder, projected=False, hse=False, spin='up', kpath=None, n=None):
         """
         Initialize parameters upon the generation of this class
 
-        Inputs:
-        ----------
-        folder: (str) This is the folder that contains the VASP files
-        projected: (bool) Determined wheter of not to parte the projected
-            eigenvalues from the vasprun.xml file. Making this true
-            increases the computational time, so only use if a projected
-            band structure is required.
-        hse: (bool) Determines if the KPOINTS file is in the form of HSE
-            or not. Only make true if the band structure was calculated
-            using a hybrid functional.
-        spin: (str) Choose which spin direction to parse. ('up' or 'down')
+        Parameters:
+            folder (str): This is the folder that contains the VASP files
+            projected (bool): Determined wheter of not to parte the projected
+                eigenvalues from the vasprun.xml file. Making this true
+                increases the computational time, so only use if a projected
+                band structure is required.
+            hse (bool): Determines if the KPOINTS file is in the form of HSE
+                or not. Only make true if the band structure was calculated
+                using a hybrid functional.
+            spin (str): Choose which spin direction to parse. ('up' or 'down')
         """
 
         self.vasprun = BSVasprun(
@@ -93,10 +111,9 @@ class Band:
         file and into a dictionary which is in the form of
         band index --> eigenvalues
 
-        Output:
-        ---------
-        bands_dict: (dict[str][np.ndarray]) Dictionary which contains
-            the eigenvalues for each band
+        Returns:
+            bands_dict (dict[str][np.ndarray]): Dictionary which contains
+                the eigenvalues for each band
         """
 
         spin = self.spin
@@ -129,10 +146,8 @@ class Band:
         from vasprun.xml into a dictionary of the form:
         band index --> atom index --> weights of orbitals
 
-        Output:
-        ----------
-        projected_dict: (dict([str][int][pd.DataFrame])) Dictionary containing the
-            projected weights of all orbitals on each atom for each band.
+        Returns:
+            projected_dict (dict([str][int][pd.DataFrame])): Dictionary containing the projected weights of all orbitals on each atom for each band.
         """
 
         spin = self.spin
@@ -189,10 +204,8 @@ class Band:
         and creates a dictionary of the form:
         band index --> s,p,d orbital weights
 
-        Outputs:
-        ----------
-        spd_dict: (dict([str][pd.DataFrame])) Dictionary that contains the summed
-            weights for the s, p, and d orbitals for each band
+        Returns:
+            spd_dict (dict([str][pd.DataFrame])): Dictionary that contains the summed weights for the s, p, and d orbitals for each band
         """
 
         # spd_orbitals = {'s': [0], 'p': [1, 2, 3], 'd': [4, 5, 6, 7, 8]}
@@ -227,30 +240,27 @@ class Band:
             returns a dictionary of the form:
             band index --> orbital index
 
-        Inputs:
-        ----------
-        orbitals: (list) List of desired orbitals. 
-            0 = s
-            1 = py
-            2 = pz
-            3 = px
-            4 = dxy
-            5 = dyz
-            6 = dz2
-            7 = dxz
-            8 = dx2-y2
-            9 = fy3x2
-            10 = fxyz
-            11 = fyz2
-            12 = fz3
-            13 = fxz2
-            14 = fzx3
-            15 = fx3
+        Parameters:
+            orbitals (list): List of desired orbitals. 
+                0 = s
+                1 = py
+                2 = pz
+                3 = px
+                4 = dxy
+                5 = dyz
+                6 = dz2
+                7 = dxz
+                8 = dx2-y2
+                9 = fy3x2
+                10 = fxyz
+                11 = fyz2
+                12 = fz3
+                13 = fxz2
+                14 = fzx3
+                15 = fx3
 
-        Outputs:
-        ----------
-        orbital_dict: (dict[str][pd.DataFrame]) Dictionary that contains the projected
-            weights of the selected orbitals.
+        Returns:
+            orbital_dict (dict[str][pd.DataFrame]): Dictionary that contains the projected weights of the selected orbitals.
         """
 
         orbital_dict = {band: np.nan for band in self.projected_dict}
@@ -276,15 +286,13 @@ class Band:
             returns a dictionary of the form:
             band index --> atom index
 
-        Inputs:
-        ----------
-        atoms: (list) List of desired atoms where atom 0 is the first atom in
-            the POSCAR file. 
+        Parameters:
+            atoms (list): List of desired atoms where atom 0 is the first atom in
+                the POSCAR file. 
 
-        Outputs:
-        ----------
-        atom_dict: (dict[str][pd.DataFrame]) Dictionary that contains the projected
-            weights of the selected atoms.
+        Returns:
+            atom_dict (dict[str][pd.DataFrame]): Dictionary that contains the projected
+                weights of the selected atoms.
         """
 
         projected_dict = self.projected_dict
@@ -306,18 +314,15 @@ class Band:
         This is useful for structures with many elements because manually entering indicies is
         not practical for large structures.
 
-        Inputs:
-        ----------
-        elements: (list) List of element symbols to sum the weights of.
-        orbitals: (bool) Determines whether or not to inclue orbitals or not
-            (True = keep orbitals, False = sum orbitals together )
-        spd: (bool) Determines whether or not to sum the s, p, and d orbitals
+        Parameters:
+            elements (list): List of element symbols to sum the weights of.
+            orbitals (bool): Determines whether or not to inclue orbitals or not
+                (True = keep orbitals, False = sum orbitals together )
+            spd (bool): Determines whether or not to sum the s, p, and d orbitals
 
 
-        Outputs:
-        ----------
-        element_dict: (dict([str][str][pd.DataFrame])) Dictionary that contains the summed
-            weights for each orbital for a given element in the structure.
+        Returns:
+            element_dict (dict([str][str][pd.DataFrame])): Dictionary that contains the summed weights for each orbital for a given element in the structure.
         """
 
         poscar = self.poscar
@@ -374,9 +379,8 @@ class Band:
         This function extracts the kpoint labels and index locations for a regular
         band structure calculation (non HSE).
 
-        Inputs:
-        ----------
-        ax: (matplotlib.pyplot.axis) Axis to append the tick labels
+        Parameters:
+            ax (matplotlib.pyplot.axis): Axis to append the tick labels
         """
 
         high_sym_points = self.kpoints.kpts
@@ -426,14 +430,13 @@ class Band:
 
     def plot_plain(self, ax, color='black', linewidth=1.25, linestyle='-'):
         """
-        This function plots a plain band structure given that the band data
-        has already been loaded with the _load_bands() method.
+        This function plots a plain band structure.
 
-        Inputs:
-        ----------
-        ax: (matplotlib.pyplot.axis) Axis to plot the data on
-        color: (str) Color of the band structure lines
-        linewidth: (float) Line width of the band structure lines
+        Parameters:
+            ax (matplotlib.pyplot.axis): Axis to plot the data on
+            color (str): Color of the band structure lines
+            linewidth (float): Line width of the band structure lines
+            linestyle (str): Line style of the bands
         """
 
         wave_vector = range(len(self.bands_dict['band1']))
@@ -458,27 +461,24 @@ class Band:
 
     def plot_spd(self, ax, scale_factor=5, order=['s', 'p', 'd'], color_dict=None, legend=True, linewidth=0.75, band_color='black'):
         """
-        This function plots the s, p, d projected band structure given that the band
-        data has already been loaded with the _load_bands() and _load_projected_bands()
-        methods
+        This function plots the s, p, d projected band structure onto a given axis
 
-        Inputs:
-        ----------
-        ax: (matplotlib.pyplot.axis) Axis to plot the data on
-        scale_factor: (float) Factor to scale weights. This changes the size of the
-            points in the scatter plot
-        order: (list) This determines the order in which the points are plotted on the
-            graph. This is an option because sometimes certain orbitals can be hidden
-            under other orbitals because they have a larger weight. For example, if the
-            signitures of the d orbitals are greater than that of the s orbitals, it
-            might be smart to choose ['d', 'p', 's'] as the order so the s orbitals are
-            plotted over the d orbitals.
-        color_dict: (dict[str][str]) This option allow the colors of the s, p, and d
-            orbitals to be specified. Should be in the form of:
-            {'s': <s color>, 'p': <p color>, 'd': <d color>}
-        legend: (bool) Determines if the legend should be included or not.
-        linewidth: (float) Line width of the plain band structure plotted in the background
-        band_color: (string) Color of the plain band structure
+        Parameters:
+            ax (matplotlib.pyplot.axis): Axis to plot the data on
+            scale_factor (float): Factor to scale weights. This changes the size of the
+                points in the scatter plot
+            order (list): This determines the order in which the points are plotted on the
+                graph. This is an option because sometimes certain orbitals can be hidden
+                under others because they have a larger weight. For example, if the
+                weights of the d orbitals are greater than that of the s orbitals, it
+                might be smart to choose ['d', 'p', 's'] as the order so the s orbitals are
+                plotted over the d orbitals.
+            color_dict (dict[str][str]): This option allow the colors of the s, p, and d
+                orbitals to be specified. Should be in the form of:
+                {'s': <s color>, 'p': <p color>, 'd': <d color>}
+            legend (bool): Determines if the legend should be included or not.
+            linewidth (float): Line width of the plain band structure plotted in the background
+            band_color (string): Color of the plain band structure
         """
 
         self.plot_plain(ax=ax, linewidth=linewidth, color=band_color)
@@ -554,26 +554,22 @@ class Band:
                 handletextpad=0.1,
             )
 
-    def plot_atom_orbitals(self, atom_orbital_pairs, ax, scale_factor=5, color_list=None, legend=True, linewidth=0.75, band_color='black'):
+    def plot_atom_orbitals(self, ax, atom_orbital_pairs, scale_factor=5, color_list=None, legend=True, linewidth=0.75, band_color='black'):
         """
-        This function plots the projected band structure of individual orbitals on
-        individual atoms given that the band data has already been loaded with the
-        _load_bands() and _load_projected_bands() methods
+        This function plots the projected band structure of individual orbitals on a given axis.
 
-        Inputs:
-        -----------
-        atom_orbital_pairs: (list[list]): Selected orbitals on selected atoms to plot.
-            This should take the form of [[atom index, orbital_index], ...]. 
-            To plot the px orbital of the 1st atom and the pz orbital of the 2nd atom
-            in the POSCAR file, the input would be [[0, 3], [1, 2]]
-        ax: (matplotlib.pyplot.axis) Axis to plot the data on
-        scale_factor: (float) Factor to scale weights. This changes the size of the
-            points in the scatter plot
-        color_dict: (dict[int][str]) Dictionary of colors for the atom-orbital pairs in       
-            the order that the atom-orbital pairs were given.
-        legend: (bool) Determines if the legend should be included or not.
-        linewidth: (float) Line width of the plain band structure plotted in the background
-        band_color: (string) Color of the plain band structure
+        Parameters:
+            ax (matplotlib.pyplot.axis): Axis to plot the data on
+            atom_orbital_pairs (list[list]): Selected orbitals on selected atoms to plot.
+                This should take the form of [[atom index, orbital_index], ...]. 
+                To plot the px orbital of the 1st atom and the pz orbital of the 2nd atom
+                in the POSCAR file, the input would be [[0, 3], [1, 2]]
+            scale_factor (float): Factor to scale weights. This changes the size of the
+                points in the scatter plot
+            color_list (list): List of colors of the same length as the atom_orbital_pairs
+            legend (bool): Determines if the legend should be included or not.
+            linewidth (float): Line width of the plain band structure plotted in the background
+            band_color (string): Color of the plain band structure
         """
 
         self.plot_plain(ax=ax, linewidth=linewidth, color=band_color)
@@ -630,24 +626,39 @@ class Band:
                 handletextpad=0.1,
             )
 
-    def plot_orbitals(self, orbitals, ax, scale_factor=5, color_dict=None, legend=True, linewidth=0.75, band_color='black'):
+    def plot_orbitals(self, ax, orbitals, scale_factor=5, color_dict=None, legend=True, linewidth=0.75, band_color='black'):
         """
-        This function plots the projected band structure of given orbitals summed
-        across all atoms given that the band data has already been loaded with the
-        _load_bands() and _load_projected_bands() methods.
+        This function plots the projected band structure of given orbitals summed across all atoms on a given axis.
 
-        Inputs:
-        ----------
-        orbitals: (list) List of orbits to compare
-        ax: (matplotlib.pyplot.axis) Axis to plot the data on
-        scale_factor: (float) Factor to scale weights. This changes the size of the
-            points in the scatter plot
-        color_dict: (dict[str][str]) This option allow the colors of each orbital
-            specified. Should be in the form of:
-            {'orbital index': <color>, 'orbital index': <color>, ...}
-        legend: (bool) Determines if the legend should be included or not.
-        linewidth: (float) Line width of the plain band structure plotted in the background
-        band_color: (string) Color of the plain band structure
+        Parameters:
+            ax (matplotlib.pyplot.axis): Axis to plot the data on
+            orbitals (list): List of orbits to compare
+
+                | 0 = s
+                | 1 = py
+                | 2 = pz
+                | 3 = px
+                | 4 = dxy
+                | 5 = dyz
+                | 6 = dz2
+                | 7 = dxz
+                | 8 = dx2-y2
+                | 9 = fy3x2
+                | 10 = fxyz
+                | 11 = fyz2
+                | 12 = fz3
+                | 13 = fxz2
+                | 14 = fzx3
+                | 15 = fx3
+
+            scale_factor (float): Factor to scale weights. This changes the size of the
+                points in the scatter plot
+            color_dict (dict[str][str]): This option allow the colors of each orbital
+                specified. Should be in the form of:
+                {'orbital index': <color>, 'orbital index': <color>, ...}
+            legend (bool): Determines if the legend should be included or not.
+            linewidth (float): Line width of the plain band structure plotted in the background
+            band_color (string): Color of the plain band structure
         """
 
         self.plot_plain(ax=ax, linewidth=linewidth, color=band_color)
@@ -714,24 +725,19 @@ class Band:
                 handletextpad=0.1,
             )
 
-    def plot_atoms(self, atoms, ax, scale_factor=5, color_list=None, legend=True, linewidth=0.75, band_color='black'):
+    def plot_atoms(self, ax, atoms, scale_factor=5, color_list=None, legend=True, linewidth=0.75, band_color='black'):
         """
-        This function plots the projected band structure of given orbitals summed
-        across all atoms given that the band data has already been loaded with the
-        _load_bands() and _load_projected_bands() methods.
+        This function plots the projected band structure of given atoms summed across all orbitals on a given axis.
 
-        Inputs:
-        ----------
-        atoms: (list) List of atoms to compare
-        ax: (matplotlib.pyplot.axis) Axis to plot the data on
-        scale_factor: (float) Factor to scale weights. This changes the size of the
-            points in the scatter plot
-        color_dict: (dict[str][str]) This option allow the colors of each atom
-            specified. Should be in the form of:
-            {'atom index': <color>, 'atom index': <color>, ...}
-        legend: (bool) Determines if the legend should be included or not.
-        linewidth: (float) Line width of the plain band structure plotted in the background
-        band_color: (string) Color of the plain band structure
+        Parameters:
+            ax (matplotlib.pyplot.axis): Axis to plot the data on
+            atoms (list): List of atoms to project onto
+            scale_factor (float): Factor to scale weights. This changes the size of the
+                points in the scatter plot
+            color_list (list): List of colors of the same length as the atoms list
+            legend (bool): Determines if the legend should be included or not.
+            linewidth (float): Line width of the plain band structure plotted in the background
+            band_color (string): Color of the plain band structure
         """
 
         self.plot_plain(ax=ax, linewidth=linewidth, color=band_color)
@@ -800,25 +806,19 @@ class Band:
                 handletextpad=0.1,
             )
 
-    def plot_elements(self, elements, ax, scale_factor=5, color_list=None, legend=True, linewidth=0.75, band_color='black'):
+    def plot_elements(self, ax, elements, scale_factor=5, color_list=None, legend=True, linewidth=0.75, band_color='black'):
         """
-        This function plots the projected band structure on specified element in
-        the calculated structure. This is useful for supercells where there are
-        many atoms of the same element and it is inconvienient to manually
-        list each index in the POSCAR.
+        This function plots the projected band structure on specified elements in the calculated structure
 
-        Inputs:
-        ----------
-        elements: (list) List of element symbols to project onto
-        ax: (matplotlib.pyplot.axis) Axis to plot the data on
-        scale_factor: (float) Factor to scale weights. This changes the size of the
-            points in the scatter plot
-        color_dict: (dict[str][str]) This option allow the colors of each element
-            specified. Should be in the form of:
-            {'element index': <color>, 'element index': <color>, ...}
-        legend: (bool) Determines if the legend should be included or not.
-        linewidth: (float) Line width of the plain band structure plotted in the background
-        band_color: (string) Color of the plain band structure
+        Parameters:
+            ax (matplotlib.pyplot.axis): Axis to plot the data on
+            elements (list): List of element symbols to project onto
+            scale_factor (float): Factor to scale weights. This changes the size of the
+                points in the scatter plot
+            color_list (list): List of colors of the same length as the elements list
+            legend (bool): Determines if the legend should be included or not.
+            linewidth (float): Line width of the plain band structure plotted in the background
+            band_color (string): Color of the plain band structure
         """
 
         self.plot_plain(ax=ax, linewidth=linewidth, color=band_color)
@@ -888,26 +888,20 @@ class Band:
                 handletextpad=0.1,
             )
 
-    def plot_element_orbitals(self, element_orbital_pairs, ax, scale_factor=5, color_list=None, legend=True, linewidth=0.75, band_color='black'):
+    def plot_element_orbitals(self, ax, element_orbital_pairs, scale_factor=5, color_list=None, legend=True, linewidth=0.75, band_color='black'):
         """
-        this function plots the projected band structure on chosen orbitals for each 
-        specified element in the calculated structure. this is useful for supercells 
-        where the are many atoms of the same element and it is inconvienient to manually
-        list each index in the poscar.
+        this function plots the projected band structure on chosen orbitals for each specified element in the calculated structure.
 
-        inputs:
-        ----------
-        elements: (list) list of element symbols to project onto
-        orbitals: (list) list of orbitals to plot for each element listed.
-        ax: (matplotlib.pyplot.axis) axis to plot the data on
-        scale_factor: (float) factor to scale weights. this changes the size of the
-            points in the scatter plot
-        color_dict: (dict[str][str]) this option allow the colors of each orbital
-            specified. should be in the form of:
-            {'orbital index': <color>, 'orbital index': <color>, ...}
-        legend: (bool) determines if the legend should be included or not.
-        linewidth: (float) line width of the plain band structure plotted in the background
-        band_color: (string) color of the plain band structure
+        Parameters:
+            ax (matplotlib.pyplot.axis): axis to plot the data on
+            element_orbital_pairs (list[list]): List of list in the form of 
+                [[element symbol, orbital index], [element symbol, orbital_index], ...]
+            scale_factor (float): factor to scale weights. this changes the size of the
+                points in the scatter plot
+            color_list (list): List of colors of the same length as the element_orbital_pairs
+            legend (bool): determines if the legend should be included or not.
+            linewidth (float): line width of the plain band structure plotted in the background
+            band_color (string): color of the plain band structure
         """
 
         self.plot_plain(ax=ax, linewidth=linewidth, color=band_color)
@@ -921,7 +915,7 @@ class Band:
         else:
             color_dict = {i: color for i, color in enumerate(color_list)}
 
-        plot_element = {element: pd.dataframe(
+        plot_element = {element: pd.DataFrame(
             columns=[range(9)]) for element in elements}
         plot_band = []
         plot_wave_vec = []
@@ -987,29 +981,25 @@ class Band:
 
     def plot_element_spd(self, elements, ax, order=['s', 'p', 'd'], scale_factor=5, color_dict=None, legend=True, linewidth=0.75, band_color='black'):
         """
-        This function plots the projected band structure on the s, p, and d orbitals
-        for each specified element in the calculated structure. This is useful for 
-        supercells where the are many atoms of the same element and it is inconvienient 
-        to manually list each index in the POSCAR.
+        This function plots the projected band structure on the s, p, and d orbitals for each specified element in the calculated structure.
 
-        Inputs:
-        ----------
-        elements: (list) List of element symbols to project onto
-        ax: (matplotlib.pyplot.axis) Axis to plot the data on
-        scale_factor: (float) Factor to scale weights. This changes the size of the
-            points in the scatter plot
-        order: (list) This determines the order in which the points are plotted on the
-            graph. This is an option because sometimes certain orbitals can be hidden
-            under other orbitals because they have a larger weight. For example, if the
-            signitures of the d orbitals are greater than that of the s orbitals, it
-            might be smart to choose ['d', 'p', 's'] as the order so the s orbitals are
-            plotted over the d orbitals.
-        color_dict: (dict[str][str]) This option allow the colors of the s, p, and d
-            orbitals to be specified. Should be in the form of:
-            {'s': <s color>, 'p': <p color>, 'd': <d color>}
-        legend: (bool) Determines if the legend should be included or not.
-        linewidth: (float) Line width of the plain band structure plotted in the background
-        band_color: (string) Color of the plain band structure
+        Parameters:
+            ax (matplotlib.pyplot.axis): Axis to plot the data on
+            elements (list): List of element symbols to project onto
+            order (list): This determines the order in which the points are plotted on the
+                graph. This is an option because sometimes certain orbitals can be hidden
+                under other orbitals because they have a larger weight. For example, if the
+                signitures of the d orbitals are greater than that of the s orbitals, it
+                might be smart to choose ['d', 'p', 's'] as the order so the s orbitals are
+                plotted over the d orbitals.
+            scale_factor (float): Factor to scale weights. This changes the size of the
+                points in the scatter plot
+            color_dict (dict[str][str]): This option allow the colors of the s, p, and d
+                orbitals to be specified. Should be in the form of:
+                {'s': <s color>, 'p': <p color>, 'd': <d color>}
+            legend (bool): Determines if the legend should be included or not.
+            linewidth (float): Line width of the plain band structure plotted in the background
+            band_color (string): Color of the plain band structure
         """
 
         self.plot_plain(ax=ax, linewidth=linewidth, color=band_color)
@@ -1096,42 +1086,3 @@ class Band:
             )
 
 
-def main():
-    # bands = Band(
-        # folder='../../vaspvis_data/hse/band',
-        # projected=True,
-        # spin='up',
-        # hse=True,
-        # kpath='GXWLGK',
-        # n=50,
-    # )
-    bands = Band(folder='../../vaspvis_data/band', projected=True)
-    fig = plt.figure(figsize=(4, 3), dpi=300)
-    ax = fig.add_subplot(111)
-    # bands._get_kticks_hse(ax=ax, kpath='GXWLGK', n=20)
-
-    # bands._get_kticks(ax=ax)
-    # bands.plot_atom_orbitals(ax=ax, atom_orbital_pairs=[[0, 0], [1, 3]])
-    # bands.plot_orbitals(ax=ax, orbitals=[1, 2, 3, 4, 5, 6, 7, 8])
-    bands.plot_spd(ax=ax, order=['s'], scale_factor=5)
-    bands.plot_spd(ax=ax, order=['p'], scale_factor=5)
-    bands.plot_spd(ax=ax, order=['d'], scale_factor=5)
-    print(ax.get_legend().legendHandles[1]._color)
-    # bands.plot_plain(ax=ax, linewidth=1)
-    # bands.plot_atoms(ax=ax, atoms=[0])
-    # element_dict = bands._sum_elements(elements=['In'])
-    # bands.plot_element_spd(ax=ax, elements=['Cd'])
-    # bands.plot_orbitals(
-    # ax=ax, orbitals=[0, 1, 2, 3, 4, 5, 6, 7, 8], scale_factor=8)
-    plt.ylim(-6, 6)
-    plt.ylabel('$E - E_F$ $(eV)$', fontsize=6)
-    plt.tick_params(labelsize=6, length=1.5)
-    plt.tick_params(axis='x', length=0)
-    # plt.tight_layout(pad=0.5)
-    # plt.legend(ncol=3, loc='upper left', fontsize=5)
-    # plt.savefig('bs_orbitals.png')
-    plt.show()
-
-
-if __name__ == "__main__":
-    main()
