@@ -12,6 +12,13 @@ import time
 
 
 class Dos:
+    """
+    This class contains all the methods for contructing density of states plots from the outputs of VASP calculations.
+
+    Parameters:
+        folder (str): This is the folder that contains the VASP files.
+        spin (str): Which spin direction to parse ('up' or 'down')
+    """
 
     def __init__(self, folder, spin='up'):
         self.folder = folder
@@ -72,10 +79,9 @@ class Dos:
         """
         This function loads the total density of states into a dictionary
 
-        Outputs:
-        ----------
-        tdos_dict: (dict[str][np.ndarray]) Dictionary that consists or the
-            energies and densities of the system.
+        Returns:
+            tdos_dict (dict[str][np.ndarray]): Dictionary that consists or the
+                energies and densities of the system.
         """
 
         if self.spin == 'up':
@@ -97,10 +103,9 @@ class Dos:
         of the form:
         atom index --> orbital projections
 
-        Outputs:
-        ----------
-        pdos_dict: (dict[int][pd.DataFrame]) Dictionary that contains a data frame
-            with the orbital weights for each atom index.
+        Returns:
+            pdos_dict (dict[int][pd.DataFrame]): Dictionary that contains a data frame
+                with the orbital weights for each atom index.
         """
 
         if self.spin == 'up':
@@ -129,15 +134,13 @@ class Dos:
         """
         This function applied a 1D gaussian filter to the density of states
 
-        Inputs:
-        ----------
-        dos: (np.ndarray) Array of densities.
-        sigma: (float) Standard deviation used in the gaussian filter.
+        Parameters:
+            dos (np.ndarray): Array of densities.
+            sigma (float): Standard deviation used in the gaussian filter.
 
 
-        Outputs:
-        ----------
-        _smeared_dos: (np.ndarray) Array of _smeared densities.
+        Returns:
+            _smeared_dos (np.ndarray): Array of _smeared densities.
         """
 
         diff = np.diff(self.tdos_dict['energy'])
@@ -151,10 +154,9 @@ class Dos:
         This function sums the weights of all orbitals for each atom
         and creates a Dataframe containing the projected densities:
 
-        Outputs:
-        ----------
-        orbital_df: (pd.DataFrame) Dataframe that has the summed densities of
-            each orbital for all atoms
+        Returns:
+            orbital_df (pd.DataFrame): Dataframe that has the summed densities of
+                each orbital for all atoms
         """
 
         atom_list = [self.pdos_dict[atom] for atom in self.pdos_dict]
@@ -169,9 +171,9 @@ class Dos:
         This function sums all the orbitals for each atom and returns a Dataframe
         of atoms with their projected densities.
 
-        Outputs:
-        atom_df: (pd.DataFrame) Dataframe containing the projected densities for
-            each atom.
+        Returns:
+            atom_df (pd.DataFrame): Dataframe containing the projected densities for
+                each atom.
         """
 
         pdos_dict = self.pdos_dict
@@ -191,18 +193,16 @@ class Dos:
         This is useful for structures with many elements because manually entering indicies is
         not practical for large structures.
 
-        Inputs:
-        ----------
-        elements: (list) List of element symbols to sum the weights of.
-        orbitals: (bool) Determines whether or not to inclue orbitals or not
-            (True = keep orbitals, False = sum orbitals together )
-        spd: (bool) Determines whether or not to sum the s, p, and d orbitals
+        Parameters:
+            elements (list): List of element symbols to sum the weights of.
+            orbitals (bool): Determines whether or not to inclue orbitals or not
+                (True = keep orbitals, False = sum orbitals together )
+            spd (bool): Determines whether or not to sum the s, p, and d orbitals
 
 
-        Outputs:
-        ----------
-        element_dict: (dict([str][str][pd.DataFrame])) Dictionary that contains the summed
-            weights for each orbital for a given element in the structure.
+        Returns:
+            element_dict (dict([str][str][pd.DataFrame])): Dictionary that contains the summed
+                weights for each orbital for a given element in the structure.
         """
 
         poscar = self.poscar
@@ -255,10 +255,9 @@ class Dos:
         This function sums the weights of the s, p, and d orbitals for each atom
         and creates a Dataframe containing the projected densities:
 
-        Outputs:
-        ----------
-        spd_df: (pd.DataFrame) Dataframe that has the summed densities of the
-            s, p, and d orbitals across all atoms.
+        Returns:
+            spd_df (pd.DataFrame): Dataframe that has the summed densities of the
+                s, p, and d orbitals across all atoms.
         """
 
         spd_df = self._sum_orbitals()
@@ -323,18 +322,20 @@ class Dos:
                     elif spin == 'down':
                         ax.set_ylim(np.min(density_in_plot) * 1.1, 0)
 
-    def plot_plain(self, ax, linewidth=1.5, fill=True, alpha=0.3, sigma=0.05, energyaxis='y', color='black', erange=[-6, 6]):
+    def plot_plain(self, ax, linewidth=1.5, fill=True, alpha=0.3, alpha_line=1.0, sigma=0.05, energyaxis='y', color='black', erange=[-6, 6]):
         """
         This function plots the total density of states
 
-        Inputs:
-        -----------
-        ax: (matplotlib.pyplot.axis) Axis to append the tick labels
-        fill: (bool) Determines wether or not to fill underneath the plot
-        alpha: (float) Alpha value for the fill
-        linewidth: (float) Linewidth of lines
-        sigma: (float) Standard deviation for gaussian filter
-        energyaxis: (str) Determines the axis to plot the energy on ('x' or 'y')
+        Parameters:
+            ax (matplotlib.pyplot.axis): Axis to append the tick labels
+            linewidth (float): Linewidth of lines
+            fill (bool): Determines wether or not to fill underneath the plot
+            alpha (float): Alpha value for the fill
+            alpha_line (float): Alpha value for the line
+            sigma (float): Standard deviation for gaussian filter
+            energyaxis (str): Determines the axis to plot the energy on ('x' or 'y')
+            color (str): Color of line
+            erange (list): Energy range for the DOS plot ([lower bound, upper bound])
         """
 
         tdos_dict = self.tdos_dict
@@ -362,6 +363,7 @@ class Dos:
                 tdos_dict['energy'],
                 linewidth=linewidth,
                 color=color,
+                alpha=alpha_line
             )
 
             if fill:
@@ -379,6 +381,7 @@ class Dos:
                 tdensity,
                 linewidth=linewidth,
                 color=color,
+                alpha=alpha_line
             )
 
             if fill:
@@ -390,24 +393,27 @@ class Dos:
                     alpha=alpha,
                 )
 
-    def plot_spd(self, ax, order=['s', 'p', 'd'], fill=True, alpha=0.3, linewidth=1.5, sigma=0.05, energyaxis='y', color_dict=None, legend=True, total=True, erange=[-6, 6]):
+    def plot_spd(self, ax, order=['s', 'p', 'd'], fill=True, alpha=0.3, alpha_line=1.0, linewidth=1.5, sigma=0.05, energyaxis='y', color_dict=None, legend=True, total=True, erange=[-6, 6]):
         """
         This function plots the total density of states with the projected
         density of states for the total projections of the s, p, and d orbitals.
 
-        Inputs:
-        ----------
-        ax: (matplotlib.pyplot.axis) Axis to plot on
-        order: (list) Order to plot the projected bands in. This feature helps to
-            avoid situations where one projection completely convers the other.
-        fill: (bool) Determines wether or not to fill underneath the plot
-        alpha: (float) Alpha value for the fill
-        linewidth: (float) Linewidth of lines
-        sigma: (float) Standard deviation for gaussian filter
-        energyaxis: (str) Determines the axis to plot the energy on ('x' or 'y')
-        color_dict: (dict[str][str]) This option allow the colors of the s, p, and d
-            orbitals to be specified. Should be in the form of:
-            {'s': <s color>, 'p': <p color>, 'd': <d color>}
+        Parameters:
+            ax (matplotlib.pyplot.axis): Axis to plot on
+            order (list): Order to plot the projected bands in. This feature helps to
+                avoid situations where one projection completely convers the other.
+            fill (bool): Determines wether or not to fill underneath the plot
+            alpha (float): Alpha value for the fill
+            alpha_line (float): Alpha value for the line
+            linewidth (float): Linewidth of lines
+            sigma (float): Standard deviation for gaussian filter
+            energyaxis (str): Determines the axis to plot the energy on ('x' or 'y')
+            color_dict (dict[str][str]): This option allow the colors of the s, p, and d
+                orbitals to be specified. Should be in the form of:
+                {'s': <s color>, 'p': <p color>, 'd': <d color>}
+            legend (bool): Determines whether to draw the legend or not
+            total (bool): Determines wheth to draw the total density of states or not
+            erange (list): Energy range for the DOS plot ([lower bound, upper bound])
         """
 
         spd_df = self._sum_spd()
@@ -430,6 +436,7 @@ class Dos:
                 linewidth=linewidth,
                 fill=fill,
                 alpha=alpha,
+                alpha_line=alpha_line,
                 sigma=sigma,
                 energyaxis=energyaxis,
                 erange=erange,
@@ -450,6 +457,7 @@ class Dos:
                     tdos_dict['energy'],
                     color=color_dict[orbital],
                     linewidth=linewidth,
+                    alpha=alpha_line
                 )
 
                 if fill:
@@ -467,6 +475,7 @@ class Dos:
                     pdensity,
                     color=color_dict[orbital],
                     linewidth=linewidth,
+                    alpha=alpha_line
                 )
 
                 if fill:
@@ -510,30 +519,32 @@ class Dos:
                 labels,
                 ncol=1,
                 loc='upper left',
-                fontsize=5,
+                fontsize=6,
                 bbox_to_anchor=(1, 1),
                 borderaxespad=0,
                 frameon=False,
                 handletextpad=0.1,
             )
 
-    def plot_atom_orbitals(self, ax, atom_orbital_pairs, fill=True, alpha=0.3, linewidth=1.5, sigma=0.05, energyaxis='y', color_list=None, legend=True, total=True, erange=[-6, 6]):
+    def plot_atom_orbitals(self, ax, atom_orbital_pairs, fill=True, alpha=0.3, alpha_line=1.0, linewidth=1.5, sigma=0.05, energyaxis='y', color_list=None, legend=True, total=True, erange=[-6, 6]):
         """
         This function plots the total density of states with the projected
-        density of states for the total projections of the s, p, and d orbitals.
+        density of states for the projections or orbitals on individual atoms.
 
-        Inputs:
-        ----------
-        ax: (matplotlib.pyplot.axis) Axis to plot on
-        order: (list) Order to plot the projected bands in. This feature helps to
-            avoid situations where one projection completely convers the other.
-        fill: (bool) Determines wether or not to fill underneath the plot
-        alpha: (float) Alpha value for the fill
-        linewidth: (float) Linewidth of lines
-        sigma: (float) Standard deviation for gaussian filter
-        energyaxis: (str) Determines the axis to plot the energy on ('x' or 'y')
-        color_dict: (dict[int][str]) Dictionary of colors for the atom-orbital pairs in       
-            the order that the atom-orbital pairs were given.
+        Parameters:
+            ax (matplotlib.pyplot.axis): Axis to plot on
+            atom_orbital_pairs (list[list]): List of atoms orbitals pairs in the form of
+                [[atom index, orbital index], [atom index, orbital index], ..]
+            fill (bool): Determines wether or not to fill underneath the plot
+            alpha (float): Alpha value for the fill
+            alpha_line (float): Alpha value for the line
+            linewidth (float): Linewidth of lines
+            sigma (float): Standard deviation for gaussian filter
+            energyaxis (str): Determines the axis to plot the energy on ('x' or 'y')
+            color_list (list): List of colors that is the same length as the atom orbitals list
+            legend (bool): Determines whether to draw the legend or not
+            total (bool): Determines wheth to draw the total density of states or not
+            erange (list): Energy range for the DOS plot ([lower bound, upper bound])
         """
 
         tdos_dict = self.tdos_dict
@@ -549,6 +560,7 @@ class Dos:
                 linewidth=linewidth,
                 fill=fill,
                 alpha=alpha,
+                alpha_line=alpha_line,
                 sigma=sigma,
                 energyaxis=energyaxis,
                 erange=erange,
@@ -572,6 +584,7 @@ class Dos:
                     tdos_dict['energy'],
                     color=color_dict[i],
                     linewidth=linewidth,
+                    alpha=alpha_line,
                 )
 
                 if fill:
@@ -589,6 +602,7 @@ class Dos:
                     pdensity,
                     color=color_dict[i],
                     linewidth=linewidth,
+                    alpha=alpha_line,
                 )
 
                 if fill:
@@ -635,30 +649,33 @@ class Dos:
                 labels,
                 ncol=1,
                 loc='upper left',
-                fontsize=5,
+                fontsize=6,
                 bbox_to_anchor=(1, 1),
                 borderaxespad=0,
                 frameon=False,
                 handletextpad=0.1,
             )
 
-    def plot_orbitals(self, ax, orbitals, fill=True, alpha=0.3, linewidth=1.5, sigma=0.05, energyaxis='y', color_dict=None, legend=True, total=True, erange=[-6, 6]):
+    def plot_orbitals(self, ax, orbitals, fill=True, alpha=0.3, alpha_line=1.0, linewidth=1.5, sigma=0.05, energyaxis='y', color_dict=None, legend=True, total=True, erange=[-6, 6]):
         """
         This function plots the total density of states with the projected
-        density of states for the total projections of the s, p, and d orbitals.
+        density of states for the projections onto given orbitals
 
-        Inputs:
-        ----------
-        ax: (matplotlib.pyplot.axis) Axis to plot on
-        orbitals: (list) List of orbitals to project onto
-        fill: (bool) Determines wether or not to fill underneath the plot
-        alpha: (float) Alpha value for the fill
-        linewidth: (float) Linewidth of lines
-        sigma: (float) Standard deviation for gaussian filter
-        energyaxis: (str) Determines the axis to plot the energy on ('x' or 'y')
-        color_dict: (dict[str][str]) This option allow the colors of each orbital
-            specified. Should be in the form of:
-            {'orbital index': <color>, 'orbital index': <color>, ...}
+        Parameters:
+            ax (matplotlib.pyplot.axis): Axis to plot on
+            orbitals (list): List of orbitals to project onto
+            fill (bool): Determines wether or not to fill underneath the plot
+            alpha (float): Alpha value for the fill
+            alpha_line (float): Alpha value for the line
+            linewidth (float): Linewidth of lines
+            sigma (float): Standard deviation for gaussian filter
+            energyaxis (str): Determines the axis to plot the energy on ('x' or 'y')
+            color_dict (dict[str][str]): This option allow the colors of each orbital
+                specified. Should be in the form of:
+                {'orbital index': <color>, 'orbital index': <color>, ...}
+            legend (bool): Determines whether to draw the legend or not
+            total (bool): Determines wheth to draw the total density of states or not
+            erange (list): Energy range for the DOS plot ([lower bound, upper bound])
         """
 
         orbital_df = self._sum_orbitals()
@@ -673,6 +690,7 @@ class Dos:
                 linewidth=linewidth,
                 fill=fill,
                 alpha=alpha,
+                alpha_line=alpha_line,
                 sigma=sigma,
                 energyaxis=energyaxis,
                 erange=erange,
@@ -693,6 +711,7 @@ class Dos:
                     tdos_dict['energy'],
                     color=color_dict[i],
                     linewidth=linewidth,
+                    alpha=alpha_line,
                 )
 
                 if fill:
@@ -710,6 +729,7 @@ class Dos:
                     pdensity,
                     color=color_dict[i],
                     linewidth=linewidth,
+                    alpha=alpha_line,
                 )
 
                 if fill:
@@ -753,31 +773,31 @@ class Dos:
                 labels,
                 ncol=1,
                 loc='upper left',
-                fontsize=5,
+                fontsize=6,
                 bbox_to_anchor=(1, 1),
                 borderaxespad=0,
                 frameon=False,
                 handletextpad=0.1,
             )
 
-    def plot_atoms(self, ax, atoms, fill=True, alpha=0.3, linewidth=1.5, sigma=0.05, energyaxis='y', color_list=None, legend=True, total=True, erange=[-6, 6]):
+    def plot_atoms(self, ax, atoms, fill=True, alpha=0.3, alpha_line=1.0, linewidth=1.5, sigma=0.05, energyaxis='y', color_list=None, legend=True, total=True, erange=[-6, 6]):
         """
-        This function plots the total density of states with the projected
-        density of states on the given atoms.
+        This function plots the total density of states with the projected density of states on the given atoms.
 
-        Inputs:
-        ----------
-        ax: (matplotlib.pyplot.axis) Axis to plot on
-        atoms: (list) Index of atoms atom plot
-        fill: (bool) Determines wether or not to fill underneath the plot
-        alpha: (float) Alpha value for the fill
-        color_dict: (dict[int][str]) Optional dictionary of colors for each atom
-        linewidth: (float) Linewidth of lines
-        sigma: (float) Standard deviation for gaussian filter
-        energyaxis: (str) Determines the axis to plot the energy on ('x' or 'y')
-        color_dict: (dict[str][str]) This option allow the colors of each atom
-            specified. Should be in the form of:
-            {'atom index': <color>, 'atom index': <color>, ...}
+        Parameters:
+            ax (matplotlib.pyplot.axis): Axis to plot on
+            atoms (list): Index of atoms to plot
+            fill (bool): Determines wether or not to fill underneath the plot
+            alpha (float): Alpha value for the fill
+            alpha_line (float): Alpha value for the line
+            color_list (list): Optional list of colors for each atom
+            linewidth (float): Linewidth of lines
+            sigma (float): Standard deviation for gaussian filter
+            energyaxis (str): Determines the axis to plot the energy on ('x' or 'y')
+            color_list (list): List of colors that is the same length at the atoms list
+            legend (bool): Determines whether to draw the legend or not
+            total (bool): Determines wheth to draw the total density of states or not
+            erange (list): Energy range for the DOS plot ([lower bound, upper bound])
         """
 
         atom_df = self._sum_atoms()
@@ -794,6 +814,7 @@ class Dos:
                 linewidth=linewidth,
                 fill=fill,
                 alpha=alpha,
+                alpha_line=alpha_line,
                 sigma=sigma,
                 energyaxis=energyaxis,
                 erange=erange,
@@ -814,6 +835,7 @@ class Dos:
                     tdos_dict['energy'],
                     color=color_dict[i],
                     linewidth=linewidth,
+                    alpha=alpha_line,
                 )
 
                 if fill:
@@ -831,6 +853,7 @@ class Dos:
                     pdensity,
                     color=color_dict[i],
                     linewidth=linewidth,
+                    alpha=alpha_line,
                 )
 
                 if fill:
@@ -874,32 +897,33 @@ class Dos:
                 labels,
                 ncol=1,
                 loc='upper left',
-                fontsize=5,
+                fontsize=6,
                 bbox_to_anchor=(1, 1),
                 borderaxespad=0,
                 frameon=False,
                 handletextpad=0.1,
             )
 
-    def plot_elements(self, ax, elements, fill=True, alpha=0.3, linewidth=1.5, sigma=0.05, energyaxis='y', color_list=None, legend=True, total=True, erange=[-6, 6]):
+    def plot_elements(self, ax, elements, fill=True, alpha=0.3, alpha_line=1.0, linewidth=1.5, sigma=0.05, energyaxis='y', color_list=None, legend=True, total=True, erange=[-6, 6]):
         """
         This function plots the total density of states with the projected
         density of states for the projection onto specified elements. This is 
         useful for supercells where there are many atoms of the same element and
         it is inconvienient to manually list each index in the POSCAR.
 
-        Inputs:
-        ----------
-        ax: (matplotlib.pyplot.axis) Axis to plot on
-        elements: (list) List of element symbols to project onto
-        fill: (bool) Determines wether or not to fill underneath the plot
-        alpha: (float) Alpha value for the fill
-        linewidth: (float) Linewidth of lines
-        sigma: (float) Standard deviation for gaussian filter
-        energyaxis: (str) Determines the axis to plot the energy on ('x' or 'y')
-        color_dict: (dict[str][str]) This option allow the colors of each element
-            specified. Should be in the form of:
-            {'element index': <color>, 'element index': <color>, ...}
+        Parameters:
+            ax (matplotlib.pyplot.axis): Axis to plot on
+            elements (list): List of element symbols to project onto
+            fill (bool): Determines wether or not to fill underneath the plot
+            alpha (float): Alpha value for the fill
+            alpha_line (float): Alpha value for the line
+            linewidth (float): Linewidth of lines
+            sigma (float): Standard deviation for gaussian filter
+            energyaxis (str): Determines the axis to plot the energy on ('x' or 'y')
+            color_list (list): List of colors that is the same length at the elements list
+            legend (bool): Determines whether to draw the legend or not
+            total (bool): Determines wheth to draw the total density of states or not
+            erange (list): Energy range for the DOS plot ([lower bound, upper bound])
         """
 
         element_dict = self._sum_elements(
@@ -917,6 +941,7 @@ class Dos:
                 linewidth=linewidth,
                 fill=fill,
                 alpha=alpha,
+                alpha_line=alpha_line,
                 sigma=sigma,
                 energyaxis=energyaxis,
                 erange=erange,
@@ -937,6 +962,7 @@ class Dos:
                     tdos_dict['energy'],
                     color=color_dict[i],
                     linewidth=linewidth,
+                    alpha=alpha_line,
                 )
 
                 if fill:
@@ -954,6 +980,7 @@ class Dos:
                     pdensity,
                     color=color_dict[i],
                     linewidth=linewidth,
+                    alpha=alpha_line,
                 )
 
                 if fill:
@@ -997,33 +1024,34 @@ class Dos:
                 labels,
                 ncol=1,
                 loc='upper left',
-                fontsize=5,
+                fontsize=6,
                 bbox_to_anchor=(1, 1),
                 borderaxespad=0,
                 frameon=False,
                 handletextpad=0.1,
             )
 
-    def plot_element_orbitals(self, ax, element_orbital_pairs, fill=True, alpha=0.3, linewidth=1.5, sigma=0.05, energyaxis='y', color_list=None, legend=True, total=True, erange=[-6, 6]):
+    def plot_element_orbitals(self, ax, element_orbital_pairs, fill=True, alpha=0.3, alpha_line=1.0, linewidth=1.5, sigma=0.05, energyaxis='y', color_list=None, legend=True, total=True, erange=[-6, 6]):
         """
         This function plots the total density of states with the projected
         density of states onto the chosen orbitals of specified elements. This is 
         useful for supercells where there are many atoms of the same element and
         it is inconvienient to manually list each index in the POSCAR.
 
-        Inputs:
-        ----------
-        ax: (matplotlib.pyplot.axis) Axis to plot on
-        elements: (list) List of element symbols to project onto
-        orbitals: (list) List of orbitals to project onto
-        fill: (bool) Determines wether or not to fill underneath the plot
-        alpha: (float) Alpha value for the fill
-        linewidth: (float) Linewidth of lines
-        sigma: (float) Standard deviation for gaussian filter
-        energyaxis: (str) Determines the axis to plot the energy on ('x' or 'y')
-        color_dict: (dict[str][str]) This option allow the colors of each element
-            specified. Should be in the form of:
-            {'element index': <color>, 'element index': <color>, ...}
+        Parameters:
+            ax (matplotlib.pyplot.axis): Axis to plot on
+            element_orbital_pairs (list[list]): List of element orbital pairs in the form of
+                [[element symbol, orbital index], [element symbol, orbital index], ..]
+            fill (bool): Determines wether or not to fill underneath the plot
+            alpha (float): Alpha value for the fill
+            alpha_line (float): Alpha value for the line
+            linewidth (float): Linewidth of lines
+            sigma (float): Standard deviation for gaussian filter
+            energyaxis (str): Determines the axis to plot the energy on ('x' or 'y')
+            color_list (list): List of colors that is the same length as the element orbitals list
+            legend (bool): Determines whether to draw the legend or not
+            total (bool): Determines wheth to draw the total density of states or not
+            erange (list): Energy range for the DOS plot ([lower bound, upper bound])
         """
 
         elements = [i[0] for i in element_orbital_pairs]
@@ -1043,6 +1071,7 @@ class Dos:
                 linewidth=linewidth,
                 fill=fill,
                 alpha=alpha,
+                alpha_line=alpha_line,
                 sigma=sigma,
                 energyaxis=energyaxis,
                 erange=erange,
@@ -1065,6 +1094,7 @@ class Dos:
                     tdos_dict['energy'],
                     color=color_dict[i],
                     linewidth=linewidth,
+                    alpha=alpha_line,
                 )
 
                 if fill:
@@ -1082,6 +1112,7 @@ class Dos:
                     pdensity,
                     color=color_dict[i],
                     linewidth=linewidth,
+                    alpha=alpha_line,
                 )
 
                 if fill:
@@ -1127,34 +1158,37 @@ class Dos:
                 labels,
                 ncol=1,
                 loc='upper left',
-                fontsize=5,
+                fontsize=6,
                 bbox_to_anchor=(1, 1),
                 borderaxespad=0,
                 frameon=False,
                 handletextpad=0.1,
             )
 
-    def plot_element_spd(self, ax, elements, order=['s', 'p', 'd'], fill=True, alpha=0.3, linewidth=1.5, sigma=0.05, energyaxis='y', color_dict=None, legend=True, total=True, erange=[-6, 6]):
+    def plot_element_spd(self, ax, elements, order=['s', 'p', 'd'], fill=True, alpha=0.3, alpha_line=1.0, linewidth=1.5, sigma=0.05, energyaxis='y', color_dict=None, legend=True, total=True, erange=[-6, 6]):
         """
         This function plots the total density of states with the projected
         density of states onto the s, p, and d orbitals of specified elements. 
         This is useful for supercells where there are many atoms of the same 
         element and it is inconvienient to manually list each index in the POSCAR.
 
-        Inputs:
-        ----------
-        ax: (matplotlib.pyplot.axis) Axis to plot on
-        elements: (list) List of element symbols to project onto
-        order: (list) Order to plot the projected bands in. This feature helps to
-            avoid situations where one projection completely convers the other.
-        fill: (bool) Determines wether or not to fill underneath the plot
-        alpha: (float) Alpha value for the fill
-        linewidth: (float) Linewidth of lines
-        sigma: (float) Standard deviation for gaussian filter
-        energyaxis: (str) Determines the axis to plot the energy on ('x' or 'y')
-        color_dict: (dict[str][str]) This option allow the colors of each element
-            specified. Should be in the form of:
-            {'element index': <color>, 'element index': <color>, ...}
+        Parameters:
+            ax (matplotlib.pyplot.axis): Axis to plot on
+            elements (list): List of element symbols to project onto
+            order (list): Order to plot the projected bands in. This feature helps to
+                avoid situations where one projection completely convers the other.
+            fill (bool): Determines wether or not to fill underneath the plot
+            alpha (float): Alpha value for the fill
+            alpha_line (float): Alpha value for the line
+            linewidth (float): Linewidth of lines
+            sigma (float): Standard deviation for gaussian filter
+            energyaxis (str): Determines the axis to plot the energy on ('x' or 'y')
+            color_dict (dict[str][str]): This option allow the colors of each element
+                specified. Should be in the form of:
+                {'element index': <color>, 'element index': <color>, ...}
+            legend (bool): Determines whether to draw the legend or not
+            total (bool): Determines wheth to draw the total density of states or not
+            erange (list): Energy range for the DOS plot ([lower bound, upper bound])
         """
 
         element_dict = self._sum_elements(
@@ -1178,6 +1212,7 @@ class Dos:
                 linewidth=linewidth,
                 fill=fill,
                 alpha=alpha,
+                alpha_line=alpha_line,
                 sigma=sigma,
                 energyaxis=energyaxis,
                 erange=erange,
@@ -1199,6 +1234,7 @@ class Dos:
                         tdos_dict['energy'],
                         color=color_dict[orbital],
                         linewidth=linewidth,
+                        alpha=alpha_line
                     )
 
                     if fill:
@@ -1216,6 +1252,7 @@ class Dos:
                         pdensity,
                         color=color_dict[orbital],
                         linewidth=linewidth,
+                        alpha=alpha_line
                     )
 
                     if fill:
@@ -1260,25 +1297,24 @@ class Dos:
                 labels,
                 ncol=1,
                 loc='upper left',
-                fontsize=5,
+                fontsize=6,
                 bbox_to_anchor=(1, 1),
                 borderaxespad=0,
                 frameon=False,
                 handletextpad=0.1,
             )
 
-    def plot_layers(self, ax, ylim=[-6, 6], cmap='magma', sigma=5, energyaxis='y'):
+    def plot_layers(self, ax, cmap='magma', sigma=5, energyaxis='y', erange=[-6, 6]):
         """
         This function plots a layer by layer heat map of the density
         of states.
 
-        Inputs:
-        ----------
-        ax: (matplotlib.pyplot.axis) Axis to plot on
-        ylim: (list) Upper and lower energy bounds for the plot.
-        cmap: (str) Color map to use in the heat map
-        sigma: (float) Sigma parameter for the _smearing of the heat map.
-        energyaxis: (str) Axis to plot the energy on. ('x' or 'y')
+        Parameters:
+            ax (matplotlib.pyplot.axis): Axis to plot on
+            ylim (list): Upper and lower energy bounds for the plot.
+            cmap (str): Color map to use in the heat map
+            sigma (float): Sigma parameter for the _smearing of the heat map.
+            energyaxis (str): Axis to plot the energy on. ('x' or 'y')
         """
 
         poscar = self.poscar
@@ -1287,7 +1323,7 @@ class Dos:
         zorder = np.argsort(zvals)
         energy = self.tdos_dict['energy']
 
-        ind = np.where((ylim[0] - 0.1 <= energy) & (energy <= ylim[-1] + 0.1))
+        ind = np.where((erange[0] - 0.1 <= energy) & (energy <= erange[-1] + 0.1))
         atom_index = range(len(zorder))
         energies = energy[ind]
         densities = self._sum_atoms().to_numpy()[ind]
@@ -1321,20 +1357,3 @@ class Dos:
         cbar.set_label('Density of States', fontsize=6)
 
 
-def main():
-    fig = plt.figure(figsize=(4, 8), dpi=200)
-    ax = fig.add_subplot(111)
-    # plt.xlim(-6, 6)
-    ax.margins(x=0.005, y=0.005)
-    dos = Dos(folder='../../vaspvis_data/dos')
-    dos.plot_spd(ax=ax, energyaxis='x')
-    dos.tdos_dict['density'] = -1 * dos.tdos_dict['density']
-    dos.spin = 'down'
-    dos.plot_spd(ax=ax, energyaxis='x', erange=[-6, 9], legend=False)
-    # dos.plot_layers(ax=ax)
-    # dos.plot_atoms(ax=ax, atoms=[0, 1], sigma=0.1, fill=True, energyaxis='y')
-    plt.show()
-
-
-if __name__ == '__main__':
-    main()
